diff --git a/build/cflags.m4 b/build/cflags.m4
index 01427d8..f331115 100644
--- a/build/cflags.m4
+++ b/build/cflags.m4
@@ -45,3 +45,26 @@ AC_DEFUN([GP_CHECK_CFLAGS],
     GP_STATUS_BUILD_FEATURE_ADD([Extra C compiler warnings],
                                 [$enable_extra_c_warnings])
 ])
+
+dnl GP_CHECK_VALA_CFLAGS
+dnl Checks for default Geany-Plugins CFLAGS used for Vala targets,
+dnl and defines GP_VALA_CFLAGS
+AC_DEFUN([GP_CHECK_VALA_CFLAGS],
+[
+    AC_ARG_ENABLE([reduced-vala-c-warnings],
+                  AS_HELP_STRING([--disable-reduced-vala-c-warnings],
+                      [Disable reduced C Compiler warnings for Vala-generated code]),
+                  [enable_reduced_vala_c_warnings=$enableval],
+                  [enable_reduced_vala_c_warnings=yes])
+
+    GP_VALA_CFLAGS=
+    AS_IF([test "x$enable_reduced_vala_c_warnings" != xno],
+    [
+        enable_reduced_vala_c_warnings=yes
+        for flag in -Wno-unused
+        do
+            _GP_CHECK_CFLAG_([$flag], [GP_VALA_CFLAGS="${GP_VALA_CFLAGS} $flag"])
+        done
+    ])
+    AC_SUBST([GP_VALA_CFLAGS])
+])
diff --git a/configure.ac b/configure.ac
index 703a853..a913e96 100644
--- a/configure.ac
+++ b/configure.ac
@@ -23,6 +23,7 @@ GP_CHECK_UNITTESTS(0.9.4)
 GP_CHECK_GTK_VERSION
 GP_CHECK_CPPCHECK
 GP_CHECK_CFLAGS
+GP_CHECK_VALA_CFLAGS
 
 dnl plugin checks
 GP_CHECK_ADDONS
diff --git a/multiterm/src/Makefile.am b/multiterm/src/Makefile.am
index 70447ff..632ffd1 100644
--- a/multiterm/src/Makefile.am
+++ b/multiterm/src/Makefile.am
@@ -25,6 +25,7 @@ multiterm_la_SOURCES = \
 
 multiterm_la_CFLAGS = \
 	$(AM_CFLAGS) \
+	$(GP_VALA_CFLAGS) \
 	$(MULTITERM_CFLAGS)
 
 multiterm_la_LIBADD = \
